import axios from "axios";

export default {
  fetchProductData({ commit, getters }, data = {}) {
    let query;
    if (data.filterColumn == "all") {
      query = "q=" + data.searchInput;
    } else if (data.filterColumn) {
      query = data.filterColumn + "_like=" + data.searchInput;
    }

    let pageLimit = `&_page=${getters.getOptions.page}&_limit=${getters.getOptions.itemsPerPage}`;
    let sort = `&_sort=${getters.getOptions.sortBy}&_order=${getters.getOptions.sortDesc}`;

    commit("setLoading", true);
    axios
      .get(`http://localhost:3000/products?${query}${pageLimit}${sort}`)
      .then((response) => {
        commit("setTotalProducts", response.headers["x-total-count"]);
        commit("setProductList", response.data);
        commit("setLoading", false);
      })
      .catch((e) => {
        console.log(e);
      });
  },

  setOptions({ commit, dispatch }, data) {
    commit("setOptions", data);
    dispatch("fetchProductData");
  },

  setExpanded({ commit }, data) {
    commit("setExpanded", data);
  },

  setSingleExpand({ commit }, data) {
    commit("setSingleExpand", data);
  },

  closeDialog({ commit }) {
    commit("setDialog", false);
  },

  deleteProduct({ dispatch, commit }, idList) {
    confirm("Are you sure you want to delete this item?") &&
      idList.forEach((id) => {
        commit("setLoading", true);

        axios
          .delete(`http://localhost:3000/products/${id}`)
          .then(() => {
            dispatch("fetchProductData");
            commit("setLoading", false);
          })
          .catch((e) => {
            console.log(e);
          });
      });
    this.itemList = [];
  },

  deleteMultiProduct({ dispatch }, items) {
    const itemList = [];
    items.forEach((item) => {
      itemList.push(item.id);
    });
    dispatch("deleteProduct", itemList);
  },

  saveProduct({ getters, dispatch, commit }) {
    const postConfig = {
      method: "post",
      url: `http://localhost:3000/products/`,
      data: getters.editedItem,
    };

    const putConfig = {
      method: "put",
      url: `http://localhost:3000/products/${getters.editedItem.id}`,
      data: getters.editedItem,
    };
    commit("setLoading", true);

    axios(!getters.editedItem.id ? postConfig : putConfig).then(() => {
      dispatch("fetchProductData");
      commit("setLoading", false);
    });
    dispatch("closeDialog");
  },

  editProduct({ commit, getters }, item) {
    commit("setEditedIndex", getters.productList.indexOf(item));
    commit("setEditedItem", Object.assign({}, item));
    commit("setDialog", true);
  },
};
